
# Parledata V0.5

écrit par Emmanuel Sandorfi
parleweb.fr
parleweb@gmail.com
Avignon, France

License : GNU GENERAL PUBLIC LICENSE


## l'efficacité par le développement

MVC (concept) + Python (langage)

## la simplicité du contenu = le savoir faire de l'entreprise

- arborescence
- classement
- fichiers bureautiques
- répertoires disque local, partagé ou cloud

## la maîtrise du site web = réduction des coûts

- automatisation des tâches
- singularité du contenu généré par modèles
- indépendance des sites et pages générés

## l'accessibilité des réalisations web

- rapidité
- référencement
- maquette ou production
- expérience utilisateur
